pub struct SelectionInfo<'a> {
first_try: FilterCounts,
relaxed_try: Option<FilterCounts>,
succeeded: bool,
in_selection: &'a RelaySelector<'a>,
}Expand description
Information about how a given selection was generated.
Records the specifics of how many relays were excluded by each requirement, whether we had to relax the selector, and so on.
The caller should typically decide whether an error or warning is necessary, and if so use this to generate a formattable report about what went wrong.
Fields
first_try: FilterCountsOutcome of our first attempt to pick a relay.
relaxed_try: Option<FilterCounts>Present if we tried again with a relaxed version of our flexible members.
succeeded: boolTrue if we eventually succeeded in picking a relay.
in_selection: &'a RelaySelector<'a>The RelaySelector that was used.
Used to produce information about which restriction is which.
Implementations
Sourceimpl<'a> SelectionInfo<'a>
impl<'a> SelectionInfo<'a>
Sourcepub fn success(&self) -> bool
pub fn success(&self) -> bool
Return true if we eventually picked at least one relay.
(We report success on pick_n_relays if we returned a nonzero
number of relays, even if it is smaller than the requested number.)
Sourcepub fn result_is_relaxed_success(&self) -> bool
pub fn result_is_relaxed_success(&self) -> bool
Return true if picked at least one relay, but only after relaxing our initial selector.